@@ -35,31 +35,24 @@ $url_params['table'] = $table;
 /**
  * Defines the urls to return to in case of error in a sql statement
  */
-$err_url_0 = $cfg['DefaultTabDatabase']
+$err_url_0 = PMA_Util::getScriptNameForOption(
+    $GLOBALS['cfg']['DefaultTabDatabase'], 'database'
+)
     . PMA_URL_getCommon(array('db' => $db));
-$err_url   = $cfg['DefaultTabTable'] . PMA_URL_getCommon($url_params);
+
+$err_url = PMA_Util::getScriptNameForOption(
+    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+)
+    . PMA_URL_getCommon($url_params);
 
 
 /**
  * Ensures the database and the table exist (else move to the "parent" script)
+ * Skip test if we are exporting as we can't tell whether a table name is an alias (which would fail the test).
  */
-require_once './libraries/db_table_exists.lib.php';
+$URL = explode('/',$_SERVER['REQUEST_URI']);
+if ($URL[2])
+        $requested_function = explode('?',$URL[2])[0];
 
-if (PMA_Tracker::isActive()
-    && PMA_Tracker::isTracked($GLOBALS["db"], $GLOBALS["table"])
-    && ! isset($_REQUEST['submit_deactivate_now'])
-    && ! (isset($_REQUEST['report_export'])
-    && $_REQUEST['export_type'] == 'sqldumpfile')
-) {
-    $temp_msg = '<a href="tbl_tracking.php' . $url_query . '">';
-    $temp_msg .= sprintf(
-        __('Tracking of %s is activated.'),
-        htmlspecialchars($GLOBALS["db"] . '.' . $GLOBALS["table"])
-    );
-    $temp_msg .= '</a>';
-
-    $msg = PMA_Message::notice($temp_msg);
-    PMA_Response::getInstance()->addHTML($msg->getDisplay());
-}
-
-?>
+if (!$URL[2] || $requested_function != 'tbl_export.php')
+        require_once './libraries/db_table_exists.lib.php';
